Crate alloy_ephemeral_lens
alloy_
ephemeral_
lens
0.2.0
All Items
Crate Items
Structs
Crate
alloy_
ephemeral_
lens
Structs

Call
Represents a contract call with encoding and decoding functionalities
Call
Result
Represents the result of a contract call
Lens
A struct that acts as a lens to interact with a smart contract proxy